(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2],{9869:function(e,s,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/success",function(){return n(7994)}])},6228:function(e,s,n){"use strict";n.d(s,{I:function(){return a},db:function(){return r}});var t=n(3977),i=n(1259);n(8887);var u=n(9828);let c=(0,t.ZF)({apiKey:"AIzaSyDLZx4QnHiTBSldEmBIELSY5QdFAio7hjw",authDomain:"tieui-8280c.firebaseapp.com",projectId:"tieui-8280c",storageBucket:"tieui-8280c.appspot.com",messagingSenderId:"731658726654",appId:"1:731658726654:web:b705f9a2a40333253fc9af",measurementId:"G-NBR7Y6Q8JD"}),r=(0,u.ad)(c),a=(0,i.v0)(c)},7994:function(e,s,n){"use strict";n.r(s);var t=n(5893),i=n(7294),u=n(6228),c=n(9828);s.default=function(){let e=new URLSearchParams(window.location.search),s=e.get("userId"),n=parseFloat(e.get("numSubs"));return(0,i.useEffect)(()=>{let e=async()=>{if(s){let e=(0,c.JU)(u.db,"users",s),t=await (0,c.QT)(e);if(t.exists()){let s=t.data();await (0,c.r7)(e,{isPaidUser:!0,NumSubscriptions:(s.NumSubscriptions||0)+n,linkedAccounts:[]})}else console.error("User not found!")}};e()},[s]),(0,t.jsxs)("div",{style:{textAlign:"center",marginTop:"50px"},children:[(0,t.jsx)("h1",{children:"Subscription Successful!"}),(0,t.jsxs)("p",{children:["Successfully subscribed for: ",s]})]})}}},function(e){e.O(0,[16,737,952,774,888,179],function(){return e(e.s=9869)}),_N_E=e.O()}]);