(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[185],{853:function(n,e,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/cancel",function(){return t(7757)}])},7757:function(n,e,t){"use strict";t.r(e);var c=t(5893);t(7294),e.default=function(){return(0,c.jsx)("div",{style:{textAlign:"center",marginTop:"50px"},children:(0,c.jsx)("h1",{children:"Subscription Was Cancelled!"})})}}},function(n){n.O(0,[774,888,179],function(){return n(n.s=853)}),_N_E=n.O()}]);