(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[782],{7972:function(e,s,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/companies",function(){return n(7985)}])},7985:function(e,s,n){"use strict";n.r(s),n.d(s,{default:function(){return q}});var i=n(5893),o=n(9008),t=n.n(o),a=n(2952),r=n(3557),l=n(8005),d=n(7357),c=n(5582),x=n(6447),p=n(5861),h=n(3321),f=n(3219),g=n(1426),j=n(633),u=n(8334),Z=n(5697),m=n.n(Z),b=n(5286),w=n(6242),y=n(4267),v=n(9661),S=n(7720);let _=e=>{let{company:s}=e;return(0,i.jsxs)(w.Z,{sx:{display:"flex",flexDirection:"column",height:"100%"},children:[(0,i.jsxs)(y.Z,{children:[(0,i.jsx)(d.Z,{sx:{display:"flex",justifyContent:"center",pb:3},children:(0,i.jsx)(v.Z,{src:s.logo,variant:"square"})}),(0,i.jsx)(p.Z,{align:"center",gutterBottom:!0,variant:"h5",children:s.title}),(0,i.jsx)(p.Z,{align:"center",variant:"body1",children:s.description})]}),(0,i.jsx)(d.Z,{sx:{flexGrow:1}}),(0,i.jsx)(S.Z,{}),(0,i.jsxs)(x.Z,{alignItems:"center",direction:"row",justifyContent:"space-between",spacing:2,sx:{p:2},children:[(0,i.jsxs)(x.Z,{alignItems:"center",direction:"row",spacing:1,children:[(0,i.jsx)(f.Z,{color:"action",fontSize:"small",children:(0,i.jsx)(b.Z,{})}),(0,i.jsx)(p.Z,{color:"text.secondary",display:"inline",variant:"body2",children:"Updated 2hr ago"})]}),(0,i.jsxs)(x.Z,{alignItems:"center",direction:"row",spacing:1,children:[(0,i.jsx)(f.Z,{color:"action",fontSize:"small",children:(0,i.jsx)(r.Z,{})}),(0,i.jsxs)(p.Z,{color:"text.secondary",display:"inline",variant:"body2",children:[s.downloads," Downloads"]})]})]})]})};_.propTypes={company:m().object.isRequired};var C=n(9396),A=n(7709),z=n(7109);let I=()=>(0,i.jsx)(w.Z,{sx:{p:2},children:(0,i.jsx)(A.Z,{defaultValue:"",fullWidth:!0,placeholder:"Search company",startAdornment:(0,i.jsx)(z.Z,{position:"start",children:(0,i.jsx)(f.Z,{color:"action",fontSize:"small",children:(0,i.jsx)(C.Z,{})})}),sx:{maxWidth:500}})}),k=[{id:"2569ce0d517a7f06d3ea1f24",createdAt:"27/03/2019",description:"Dropbox is a file hosting service that offers cloud storage, file synchronization, a personal cloud.",logo:"/assets/logos/logo-dropbox.png",title:"Dropbox",downloads:"594"},{id:"ed2b900870ceba72d203ec15",createdAt:"31/03/2019",description:"Medium is an online publishing platform developed by Evan Williams, and launched in August 2012.",logo:"/assets/logos/logo-medium.png",title:"Medium Corporation",downloads:"625"},{id:"a033e38768c82fca90df3db7",createdAt:"03/04/2019",description:"Slack is a cloud-based set of team collaboration tools and services, founded by Stewart Butterfield.",logo:"/assets/logos/logo-slack.png",title:"Slack",downloads:"857"},{id:"1efecb2bf6a51def9869ab0f",createdAt:"04/04/2019",description:"Lyft is an on-demand transportation company based in San Francisco, California.",logo:"/assets/logos/logo-lyft.png",title:"Lyft",downloads:"406"},{id:"1ed68149f65fbc6089b5fd07",createdAt:"04/04/2019",description:"GitHub is a web-based hosting service for version control of code using Git.",logo:"/assets/logos/logo-github.png",title:"GitHub",downloads:"835"},{id:"5dab321376eff6177407e887",createdAt:"04/04/2019",description:"Squarespace provides software as a service for website building and hosting. Headquartered in NYC.",logo:"/assets/logos/logo-squarespace.png",title:"Squarespace",downloads:"835"}],E=()=>(0,i.jsxs)(i.Fragment,{children:[(0,i.jsx)(t(),{children:(0,i.jsx)("title",{children:"Companies | TieUi"})}),(0,i.jsx)(d.Z,{component:"main",sx:{flexGrow:1,py:8},children:(0,i.jsx)(c.Z,{maxWidth:"xl",children:(0,i.jsxs)(x.Z,{spacing:3,children:[(0,i.jsxs)(x.Z,{direction:"row",justifyContent:"space-between",spacing:4,children:[(0,i.jsxs)(x.Z,{spacing:1,children:[(0,i.jsx)(p.Z,{variant:"h4",children:"Companies"}),(0,i.jsxs)(x.Z,{alignItems:"center",direction:"row",spacing:1,children:[(0,i.jsx)(h.Z,{color:"inherit",startIcon:(0,i.jsx)(f.Z,{fontSize:"small",children:(0,i.jsx)(a.Z,{})}),children:"Import"}),(0,i.jsx)(h.Z,{color:"inherit",startIcon:(0,i.jsx)(f.Z,{fontSize:"small",children:(0,i.jsx)(r.Z,{})}),children:"Export"})]})]}),(0,i.jsx)("div",{children:(0,i.jsx)(h.Z,{startIcon:(0,i.jsx)(f.Z,{fontSize:"small",children:(0,i.jsx)(l.Z,{})}),variant:"contained",children:"Add"})})]}),(0,i.jsx)(I,{}),(0,i.jsx)(g.Z,{container:!0,spacing:3,children:k.map(e=>(0,i.jsx)(g.Z,{xs:12,md:6,lg:4,children:(0,i.jsx)(_,{company:e})},e.id))}),(0,i.jsx)(d.Z,{sx:{display:"flex",justifyContent:"center"},children:(0,i.jsx)(j.Z,{count:3,size:"small"})})]})})})]});E.getLayout=e=>(0,i.jsx)(u.A,{children:e});var q=E}},function(e){e.O(0,[16,737,321,952,177,664,850,688,11,158,334,774,888,179],function(){return e(e.s=7972)}),_N_E=e.O()}]);